@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import functools
 import html
 import os
 import re
@@ -17,6 +18,7 @@ from mkdocs_include_markdown_plugin.cache import Cache
 from mkdocs_include_markdown_plugin.directive import (
     ARGUMENT_REGEXES,
     GLOB_FLAGS,
+    create_include_tag,
     parse_bool_options,
     parse_filename_argument,
     parse_string_argument,
@@ -81,21 +83,20 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         http_cache: Cache | None = None,
 ) -> str:
     """Return the content of the file to include."""
-    settings_ignore_paths = []
-    if settings.exclude is not None:
-        for path in glob.glob(
-                [
-                    os.path.join(docs_dir, fp)
-                    if not os.path.isabs(fp)
-                    else fp for fp in settings.exclude
-                ],
-                flags=GLOB_FLAGS,
-                root_dir=docs_dir,
-        ):
-            if path not in settings_ignore_paths:
-                settings_ignore_paths.append(path)
+    if settings.exclude:
+        settings_ignore_paths = list(glob.glob(
+            [
+                os.path.join(docs_dir, fp)
+                if not os.path.isabs(fp)
+                else fp for fp in settings.exclude
+            ],
+            flags=GLOB_FLAGS,
+            root_dir=docs_dir,
+        ))
         if page_src_path in settings_ignore_paths:
             return markdown
+    else:
+        settings_ignore_paths = []
 
     new_found_include_contents: list[tuple[str, str]] = []
     new_found_include_markdown_contents: list[tuple[str, str]] = []
@@ -104,7 +105,8 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             match: re.Match[str],
     ) -> str:
         directive_match_start = match.start()
-        directive_lineno = process.lineno_from_content_start(
+        directive_lineno = functools.partial(
+            process.lineno_from_content_start,
             markdown,
             directive_match_start,
         )
@@ -114,7 +116,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         filename, raw_filename = parse_filename_argument(match)
         if filename is None:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 "Found no path passed including with 'include'"
@@ -131,13 +133,13 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             docs_dir,
         )
 
-        exclude_match = ARGUMENT_REGEXES['exclude'].search(arguments_string)
+        exclude_match = ARGUMENT_REGEXES['exclude']().search(arguments_string)
         ignore_paths = [*settings_ignore_paths]
         if exclude_match is not None:
             exclude_string = parse_string_argument(exclude_match)
             if exclude_string is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'exclude' argument in 'include'"
@@ -147,8 +149,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             for path in resolve_file_paths_to_exclude(
                 exclude_string, page_src_path, docs_dir,
             ):
-                if path not in ignore_paths:
-                    ignore_paths.append(path)
+                ignore_paths.append(path)
 
         file_paths_to_include, is_url = resolve_file_paths_to_include(
             filename,
@@ -159,7 +160,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
 
         if not file_paths_to_include:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 f"No files found including '{raw_filename}' at {location}",
@@ -176,7 +177,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         )
         if invalid_bool_args:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 f"Invalid value for '{invalid_bool_args[0]}' argument of"
@@ -184,12 +185,12 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                 f' Possible values are true or false.',
             )
 
-        start_match = ARGUMENT_REGEXES['start'].search(arguments_string)
+        start_match = ARGUMENT_REGEXES['start']().search(arguments_string)
         if start_match:
             start = parse_string_argument(start_match)
             if start is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'start' argument in 'include' directive at"
@@ -198,12 +199,12 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         else:
             start = defaults['start']
 
-        end_match = ARGUMENT_REGEXES['end'].search(arguments_string)
+        end_match = ARGUMENT_REGEXES['end']().search(arguments_string)
         if end_match:
             end = parse_string_argument(end_match)
             if end is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'end' argument in 'include' directive at"
@@ -212,12 +213,13 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         else:
             end = defaults['end']
 
-        encoding_match = ARGUMENT_REGEXES['encoding'].search(arguments_string)
+        encoding_match = ARGUMENT_REGEXES['encoding']().search(
+            arguments_string)
         if encoding_match:
             encoding = parse_string_argument(encoding_match)
             if encoding is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'encoding' argument in 'include'"
@@ -294,7 +296,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                 ])
                 plural_suffix = 's' if len(file_paths_to_include) > 1 else ''
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 logger.warning(
                     f"Delimiter {delimiter_name} '{delimiter_value}'"
@@ -313,7 +315,8 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             match: re.Match[str],
     ) -> str:
         directive_match_start = match.start()
-        directive_lineno = process.lineno_from_content_start(
+        directive_lineno = functools.partial(
+            process.lineno_from_content_start,
             markdown,
             directive_match_start,
         )
@@ -324,7 +327,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         filename, raw_filename = parse_filename_argument(match)
         if filename is None:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 "Found no path passed including with 'include-markdown'"
@@ -341,13 +344,13 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             docs_dir,
         )
 
-        exclude_match = ARGUMENT_REGEXES['exclude'].search(arguments_string)
+        exclude_match = ARGUMENT_REGEXES['exclude']().search(arguments_string)
         ignore_paths = [*settings_ignore_paths]
         if exclude_match is not None:
             exclude_string = parse_string_argument(exclude_match)
             if exclude_string is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'exclude' argument in 'include-markdown'"
@@ -356,8 +359,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             for path in resolve_file_paths_to_exclude(
                 exclude_string, page_src_path, docs_dir,
             ):
-                if path not in ignore_paths:
-                    ignore_paths.append(path)
+                ignore_paths.append(path)
 
         file_paths_to_include, is_url = resolve_file_paths_to_include(
             filename,
@@ -368,7 +370,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
 
         if not file_paths_to_include:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 f"No files found including '{raw_filename}' at {location}",
@@ -388,7 +390,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         )
         if invalid_bool_args:
             location = process.file_lineno_message(
-                page_src_path, docs_dir, directive_lineno,
+                page_src_path, docs_dir, directive_lineno(),
             )
             raise PluginError(
                 f"Invalid value for '{invalid_bool_args[0]}' argument of"
@@ -397,12 +399,12 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             )
 
         # start and end arguments
-        start_match = ARGUMENT_REGEXES['start'].search(arguments_string)
+        start_match = ARGUMENT_REGEXES['start']().search(arguments_string)
         if start_match:
             start = parse_string_argument(start_match)
             if start is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'start' argument in 'include-markdown'"
@@ -411,12 +413,12 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         else:
             start = defaults['start']
 
-        end_match = ARGUMENT_REGEXES['end'].search(arguments_string)
+        end_match = ARGUMENT_REGEXES['end']().search(arguments_string)
         if end_match:
             end = parse_string_argument(end_match)
             if end is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'end' argument in 'include-markdown'"
@@ -425,12 +427,13 @@ def get_file_content(  # noqa: PLR0913, PLR0915
         else:
             end = defaults['end']
 
-        encoding_match = ARGUMENT_REGEXES['encoding'].search(arguments_string)
+        encoding_match = ARGUMENT_REGEXES['encoding']().search(
+            arguments_string)
         if encoding_match:
             encoding = parse_string_argument(encoding_match)
             if encoding is None:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'encoding' argument in 'include-markdown'"
@@ -440,14 +443,14 @@ def get_file_content(  # noqa: PLR0913, PLR0915
             encoding = defaults['encoding']
 
         # heading offset
-        offset_match = ARGUMENT_REGEXES['heading-offset'].search(
+        offset_match = ARGUMENT_REGEXES['heading-offset']().search(
             arguments_string,
         )
         if offset_match:
             offset_raw_value = offset_match[1]
             if offset_raw_value == '':
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     "Invalid empty 'heading-offset' argument in"
@@ -457,7 +460,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                 offset = int(offset_raw_value)
             except ValueError:
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 raise PluginError(
                     f"Invalid 'heading-offset' argument \"{offset_raw_value}\""
@@ -579,7 +582,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                 ])
                 plural_suffix = 's' if len(file_paths_to_include) > 1 else ''
                 location = process.file_lineno_message(
-                    page_src_path, docs_dir, directive_lineno,
+                    page_src_path, docs_dir, directive_lineno(),
                 )
                 logger.warning(
                     f"Delimiter {delimiter_name} '{delimiter_value}' of"
@@ -630,8 +633,16 @@ def on_page_markdown(
         page.file.abs_src_path,
         docs_dir,
         {
-            'include': plugin._include_tag(),
-            'include-markdown': plugin._include_markdown_tag(),
+            'include': create_include_tag(
+                config.opening_tag,
+                config.closing_tag,
+                config.directives.get('include', 'include'),
+            ),
+            'include-markdown': create_include_tag(
+                config.opening_tag,
+                config.closing_tag,
+                config.directives.get('include-markdown', 'include-markdown'),
+            ),
         },
         {
             'encoding': config.encoding,
