@@ -112,6 +112,49 @@ MARKDOWN_LINK_DEFINITION_REGEX = re.compile(
     flags=re.VERBOSE | re.MULTILINE,
 )
 
+# Matched html image and source definition.
+# e.g. <img src="path/to/image.png" alt="alt-text">
+# e.g. <source src="path/to/image.png" alt="alt-text">
+MARKDOWN_HTML_IMAGE_REGEX = re.compile(
+    r'''
+        <(?:img|source)    # img or source
+        (?:\s+             # More than one whitespace
+            (?!src=)       # Not src=
+            [\w-]+         # attribute name
+            (?:\s*=\s*)?   # arbitrary whitespace (optional)
+            (?:
+                "[^"]*"    # Quoted value (double quote)
+                |
+                '[^']*'    # Quoted value (single quote)
+            )?
+        )*                 # Other attributes are repeated 0 or more times
+        \s+                # More than one whitespace
+        src=["'](\S+?)["'] # src = $1 (double quote or single quote)
+    ''',
+    flags=re.VERBOSE | re.MULTILINE,
+)
+
+# Matched html anchor definition.
+# e.g. <a href="https://example.com">example</a>
+MARKDOWN_HTML_ANCHOR_DEFINITION_REGEX = re.compile(
+    r'''
+        <a
+        (?:\s+             # More than one whitespace
+            (?!href=)      # Not href=
+            [\w-]+         # attribute name
+            (?:\s*=\s*)?   # arbitrary whitespace (optional)
+            (?:
+                "[^"]*"    # Quoted value (double quote)
+                |
+                '[^']*'    # Quoted value (single quote)
+            )?
+        )*                 # Other attributes are repeated 0 or more times
+        \s+                # More than one whitespace
+        href=["'](\S+?)["']# href = $1 (double quote or single quote)
+    ''',
+    flags=re.VERBOSE | re.MULTILINE,
+)
+
 
 def transform_p_by_p_skipping_codeblocks(  # noqa: PLR0912, PLR0915
         markdown: str,
@@ -244,10 +287,10 @@ def rewrite_relative_urls(
     ``source_path`` will still work when inserted into a file at
     ``destination_path``.
     """
-    def rewrite_url(url: str) -> str:
-        from urllib.parse import urlparse, urlunparse
+    from urllib.parse import urlparse, urlunparse
 
-        if is_relative_path(url):
+    def rewrite_url(url: str) -> str:
+        if is_url(url):
             return url
 
         scheme, netloc, path, params, query, fragment = urlparse(url)
@@ -299,10 +342,18 @@ def rewrite_relative_urls(
             found_href_url_group_index_3,
             paragraph,
         )
-        return MARKDOWN_LINK_DEFINITION_REGEX.sub(
+        paragraph = MARKDOWN_LINK_DEFINITION_REGEX.sub(
             functools.partial(found_href, url_group_index=2),
             paragraph,
         )
+        paragraph = MARKDOWN_HTML_IMAGE_REGEX.sub(
+            functools.partial(found_href, url_group_index=1),
+            paragraph,
+        )
+        return MARKDOWN_HTML_ANCHOR_DEFINITION_REGEX.sub(
+            functools.partial(found_href, url_group_index=1),
+            paragraph,
+        )
 
     return transform_p_by_p_skipping_codeblocks(
         markdown,
@@ -425,7 +476,7 @@ def increase_headings_offset(markdown: str, offset: int = 0) -> str:
 
 def rstrip_trailing_newlines(content: str) -> str:
     """Removes trailing newlines from a string."""
-    while content.endswith('\n') or content.endswith('\r'):
+    while content.endswith(('\n', '\r')):
         content = content.rstrip('\r\n')
     return content
 
